@@ -9,7 +9,6 @@ data <- data.frame(x=x,y=y)
 
 cf <- covafill(coord = data$x,
                obs = data$y,
-               h = 2.0,
                p = as.integer(3))
 
 
@@ -17,5 +16,5 @@ cf$predict(0,TRUE)
 
 ggplot(aes(x=x,y=y),data=data) +
     geom_point() +
-    stat_covafill(bandwith=1,polyDegree=3L)+
-geom_label(aes(x=x,y=y,label=label,hjust=0),data=data.frame(x=0,y=-25,label="ggplot(aes(x=x,y=y),data=data) +\n\tgeom_point() +\n\tstat_covafill(bandwith=1,polyDegree=3L)"))
+    stat_covafill(polyDegree=3L)+
+geom_label(aes(x=x,y=y,label=label,hjust=0),data=data.frame(x=0,y=-25,label="ggplot(aes(x=x,y=y),data=data) +\n\tgeom_point() +\n\tstat_covafill(polyDegree=3L)"))
